@@ -36,14 +36,19 @@ class DbResourceForm extends Form
         if (Platform::hasMssqlSupport()) {
             $dbChoices['mssql'] = 'MSSQL';
         }
+        if (Platform::hasIbmSupport()) {
+            $dbChoices['ibm'] = 'IBM (DB2)';
+        }
         if (Platform::hasOracleSupport()) {
             $dbChoices['oracle'] = 'Oracle';
         }
         if (Platform::hasOciSupport()) {
             $dbChoices['oci'] = 'Oracle (OCI8)';
         }
+        if (Platform::hasSqliteSupport()) {
+            $dbChoices['sqlite'] = 'SQLite';
+        }
 
-        $offerSsl = false;
         $offerPostgres = false;
         $offerMysql = false;
         $dbChoice = isset($formData['db']) ? $formData['db'] : key($dbChoices);
@@ -51,9 +56,12 @@ class DbResourceForm extends Form
             $offerPostgres = true;
         } elseif ($dbChoice === 'mysql') {
             $offerMysql = true;
-            if (version_compare(Platform::getPhpVersion(), '5.4.0', '>=')) {
-                $offerSsl = true;
-            }
+        }
+
+        if ($dbChoice === 'oracle' || $dbChoice === 'oci') {
+            $hostIsRequired = false;
+        } else {
+            $hostIsRequired = true;
         }
 
         $socketInfo = '';
@@ -87,75 +95,76 @@ class DbResourceForm extends Form
                 'multiOptions'  => $dbChoices
             )
         );
-        $this->addElement(
-            'text',
-            'host',
-            array (
-                'required'      => true,
-                'label'         => $this->translate('Host'),
-                'description'   => $this->translate('The hostname of the database')
-                    . ($socketInfo ? '. ' . $socketInfo : ''),
-                'value'         => 'localhost'
-            )
-        );
-        $this->addElement(
-            'number',
-            'port',
-            array(
-                'description'       => $this->translate('The port to use'),
-                'label'             => $this->translate('Port'),
-                'preserveDefault'   => true,
-                'required'          => $offerPostgres,
-                'value'             => $offerPostgres ? 5432 : null
-            )
-        );
-        $this->addElement(
-            'text',
-            'dbname',
-            array(
-                'required'      => true,
-                'label'         => $this->translate('Database Name'),
-                'description'   => $this->translate('The name of the database to use')
-            )
-        );
-        $this->addElement(
-            'text',
-            'username',
-            array (
-                'required'      => true,
-                'label'         => $this->translate('Username'),
-                'description'   => $this->translate('The user name to use for authentication')
-            )
-        );
-        $this->addElement(
-            'password',
-            'password',
-            array(
-                'renderPassword'    => true,
-                'label'             => $this->translate('Password'),
-                'description'       => $this->translate('The password to use for authentication')
-            )
-        );
-        $this->addElement(
-            'text',
-            'charset',
-            array (
-                'description'   => $this->translate('The character set for the database'),
-                'label'         => $this->translate('Character Set')
-            )
-        );
-        $this->addElement(
-            'checkbox',
-            'persistent',
-            array(
-                'description'   => $this->translate(
-                    'Check this box for persistent database connections. Persistent connections are not closed at the'
-                    . ' end of a request, but are cached and re-used. This is experimental'
-                ),
-                'label'         => $this->translate('Persistent')
-            )
-        );
-        if ($offerSsl) {
+        if ($dbChoice === 'sqlite') {
+            $this->addElement(
+                'text',
+                'dbname',
+                array(
+                    'required'      => true,
+                    'label'         => $this->translate('Database Name'),
+                    'description'   => $this->translate('The name of the database to use')
+                )
+            );
+        } else {
+            $this->addElement(
+                'text',
+                'host',
+                array (
+                    'required'      => $hostIsRequired,
+                    'label'         => $this->translate('Host'),
+                    'description'   => $this->translate('The hostname of the database')
+                        . ($socketInfo ? '. ' . $socketInfo : ''),
+                    'value'         => $hostIsRequired ? 'localhost' : ''
+                )
+            );
+            $this->addElement(
+                'number',
+                'port',
+                array(
+                    'description'       => $this->translate('The port to use'),
+                    'label'             => $this->translate('Port'),
+                    'preserveDefault'   => true,
+                    'required'          => $offerPostgres,
+                    'value'             => $offerPostgres ? 5432 : null
+                )
+            );
+            $this->addElement(
+                'text',
+                'dbname',
+                array(
+                    'required'      => true,
+                    'label'         => $this->translate('Database Name'),
+                    'description'   => $this->translate('The name of the database to use')
+                )
+            );
+            $this->addElement(
+                'text',
+                'username',
+                array (
+                    'required'      => true,
+                    'label'         => $this->translate('Username'),
+                    'description'   => $this->translate('The user name to use for authentication')
+                )
+            );
+            $this->addElement(
+                'password',
+                'password',
+                array(
+                    'required'          => true,
+                    'renderPassword'    => true,
+                    'label'             => $this->translate('Password'),
+                    'description'       => $this->translate('The password to use for authentication'),
+                    'autocomplete'      => 'new-password'
+                )
+            );
+            $this->addElement(
+                'text',
+                'charset',
+                array (
+                    'description'   => $this->translate('The character set for the database'),
+                    'label'         => $this->translate('Character Set')
+                )
+            );
             $this->addElement(
                 'checkbox',
                 'use_ssl',
@@ -168,6 +177,18 @@ class DbResourceForm extends Form
                 )
             );
             if (isset($formData['use_ssl']) && $formData['use_ssl']) {
+                if (defined('\PDO::MYSQL_ATTR_SSL_VERIFY_SERVER_CERT')) {
+                    $this->addElement(
+                        'checkbox',
+                        'ssl_do_not_verify_server_cert',
+                        array(
+                            'label'             => $this->translate('SSL Do Not Verify Server Certificate'),
+                            'description'       => $this->translate(
+                                'Whether to disable verification of the server certificate'
+                            )
+                        )
+                    );
+                }
                 $this->addElement(
                     'text',
                     'ssl_key',
