@@ -15,10 +15,10 @@ use Icinga\Forms\ConfigForm;
 use Icinga\Forms\Config\Resource\DbResourceForm;
 use Icinga\Forms\Config\Resource\FileResourceForm;
 use Icinga\Forms\Config\Resource\LdapResourceForm;
-use Icinga\Forms\Config\Resource\LivestatusResourceForm;
 use Icinga\Forms\Config\Resource\SshResourceForm;
 use Icinga\Web\Form;
 use Icinga\Web\Notification;
+use Zend_Form_Element;
 
 class ResourceConfigForm extends ConfigForm
 {
@@ -59,8 +59,6 @@ class ResourceConfigForm extends ConfigForm
             return new DbResourceForm();
         } elseif ($type === 'ldap') {
             return new LdapResourceForm();
-        } elseif ($type === 'livestatus') {
-            return new LivestatusResourceForm();
         } elseif ($type === 'file') {
             return new FileResourceForm();
         } elseif ($type === 'ssh') {
@@ -101,7 +99,7 @@ class ResourceConfigForm extends ConfigForm
      * @param   string      $name           The name of the resource to edit
      * @param   array       $values         The values to edit the configuration with
      *
-     * @return  array                       The edited configuration
+     * @return  ConfigObject                The edited configuration
      *
      * @throws  InvalidArgumentException    In case the resource does not exist
      */
@@ -137,7 +135,7 @@ class ResourceConfigForm extends ConfigForm
      *
      * @param   string      $name           The name of the resource to remove
      *
-     * @return  array                       The removed resource configuration
+     * @return  ConfigObject                The removed resource configuration
      *
      * @throws  InvalidArgumentException    In case the resource does not exist
      */
@@ -262,7 +260,6 @@ class ResourceConfigForm extends ConfigForm
 
         $resourceTypes = array(
             'file'          => $this->translate('File'),
-            'livestatus'    => 'Livestatus',
             'ssh'           => $this->translate('SSH Identity'),
         );
         if ($resourceType === 'ldap' || Platform::hasLdapSupport()) {
@@ -298,7 +295,7 @@ class ResourceConfigForm extends ConfigForm
      *
      * @param   Form    $form
      *
-     * @return  Inspection
+     * @return  ?Inspection
      */
     public static function inspectResource(Form $form)
     {
@@ -324,8 +321,8 @@ class ResourceConfigForm extends ConfigForm
         if ($this->getElement('resource_validation')->isChecked() && parent::isValid($formData)) {
             $inspection = static::inspectResource($this);
             if ($inspection !== null) {
-                $join = function ($e) use (& $join) {
-                    return is_string($e) ? $e : join("\n", array_map($join, $e));
+                $join = function ($e) use (&$join) {
+                    return is_array($e) ? join("\n", array_map($join, $e)) : $e;
                 };
                 $this->addElement(
                     'note',
