@@ -213,7 +213,7 @@ class NavigationConfigForm extends ConfigForm
 
         $names = array();
         foreach ($this->getShareConfig($type) as $sectionName => $sectionConfig) {
-            if ($sectionName !== $this->itemToLoad
+            if ((string) $sectionName !== $this->itemToLoad
                 && $sectionConfig->owner === ($owner ?: $this->getUser()->getUsername())
                 && ! in_array($sectionName, $children, true)
             ) {
@@ -222,7 +222,7 @@ class NavigationConfigForm extends ConfigForm
         }
 
         foreach ($this->getUserConfig($type) as $sectionName => $sectionConfig) {
-            if ($sectionName !== $this->itemToLoad
+            if ((string) $sectionName !== $this->itemToLoad
                 && ! in_array($sectionName, $children, true)
             ) {
                 $names[] = $sectionName;
@@ -299,7 +299,7 @@ class NavigationConfigForm extends ConfigForm
         $shared = false;
         $config = $this->getUserConfig($data['type']);
         if ((isset($data['users']) && $data['users']) || (isset($data['groups']) && $data['groups'])) {
-            if ($this->getUser()->can('application/share/navigation')) {
+            if ($this->getUser()->can('user/share/navigation')) {
                 $data['owner'] = $this->getUser()->getUsername();
                 $config = $this->getShareConfig($data['type']);
                 $shared = true;
@@ -370,7 +370,7 @@ class NavigationConfigForm extends ConfigForm
                 $config = $this->unshare($name, isset($data['parent']) ? $data['parent'] : null);
             }
         } elseif ((isset($data['users']) && $data['users']) || (isset($data['groups']) && $data['groups'])) {
-            if ($this->getUser()->can('application/share/navigation')) {
+            if ($this->getUser()->can('user/share/navigation')) {
                 // It is not shared yet but should be
                 $this->secondaryConfig = $config;
                 $config = $this->getShareConfig();
@@ -580,7 +580,7 @@ class NavigationConfigForm extends ConfigForm
         );
 
         if ((! $itemForm->requiresParentSelection() || ! isset($formData['parent']) || ! $formData['parent'])
-            && $this->getUser()->can('application/share/navigation')
+            && $this->getUser()->can('user/share/navigation')
         ) {
             $checked = isset($formData['shared']) ? null : (isset($formData['users']) || isset($formData['groups']));
 
@@ -662,12 +662,12 @@ class NavigationConfigForm extends ConfigForm
                         'The parent item to assign this navigation item to. '
                         . 'Select "None" to make this a main navigation item'
                     ),
-                    'multiOptions'  => array_merge(
-                        array('' => $this->translate('None', 'No parent for a navigation item')),
-                        empty($availableParents) ? array() : array_combine($availableParents, $availableParents)
-                    )
+                    'multiOptions'  => ['' => $this->translate('None', 'No parent for a navigation item')]
+                        + (empty($availableParents) ? [] : array_combine($availableParents, $availableParents))
                 )
             );
+        } else {
+            $this->addElement('hidden', 'parent', ['disabled'  => true]);
         }
 
         $this->addSubForm($itemForm, 'item_form');
@@ -783,7 +783,7 @@ class NavigationConfigForm extends ConfigForm
             return $this->getUserConfig();
         } elseif ($this->getShareConfig()->hasSection($name)) {
             if ($this->getShareConfig()->get($name, 'owner') === $this->getUser()->getUsername()
-                || $this->getUser()->can('config/application/navigation')
+                || $this->getUser()->can('user/share/navigation')
             ) {
                 return $this->getShareConfig();
             }
@@ -815,6 +815,7 @@ class NavigationConfigForm extends ConfigForm
         $className = StringHelper::cname($type, '-') . 'Form';
 
         $form = null;
+        $classPath = null;
         foreach (Icinga::app()->getModuleManager()->getLoadedModules() as $module) {
             $classPath = 'Icinga\\Module\\'
                 . ucfirst($module->getName())
