@@ -4,17 +4,19 @@
 namespace Icinga\Authentication\User;
 
 use DateTime;
+use Exception;
 use Icinga\Data\ConfigObject;
 use Icinga\Data\Inspectable;
 use Icinga\Data\Inspection;
 use Icinga\Exception\AuthenticationException;
 use Icinga\Exception\ProgrammingError;
+use Icinga\Exception\QueryException;
 use Icinga\Repository\LdapRepository;
 use Icinga\Repository\RepositoryQuery;
 use Icinga\Protocol\Ldap\LdapException;
 use Icinga\User;
 
-class LdapUserBackend extends LdapRepository implements UserBackendInterface, Inspectable
+class LdapUserBackend extends LdapRepository implements UserBackendInterface, DomainAwareInterface, Inspectable
 {
     /**
      * The base DN to use for a query
@@ -44,6 +46,13 @@ class LdapUserBackend extends LdapRepository implements UserBackendInterface, In
      */
     protected $filter;
 
+    /**
+     * The domain the backend is responsible for
+     *
+     * @var string
+     */
+    protected $domain;
+
     /**
      * The columns which are not permitted to be queried
      *
@@ -81,7 +90,7 @@ class LdapUserBackend extends LdapRepository implements UserBackendInterface, In
      */
     public function setBaseDn($baseDn)
     {
-        if (($baseDn = trim($baseDn))) {
+        if ($baseDn && ($baseDn = trim($baseDn))) {
             $this->baseDn = $baseDn;
         }
 
@@ -153,7 +162,7 @@ class LdapUserBackend extends LdapRepository implements UserBackendInterface, In
      */
     public function setFilter($filter)
     {
-        if (($filter = trim($filter))) {
+        if ($filter && ($filter = trim($filter))) {
             if ($filter[0] === '(') {
                 $filter = substr($filter, 1, -1);
             }
@@ -174,20 +183,25 @@ class LdapUserBackend extends LdapRepository implements UserBackendInterface, In
         return $this->filter;
     }
 
+    public function getDomain()
+    {
+        return $this->domain;
+    }
+
     /**
-     * Apply the given configuration to this backend
+     * Set the domain the backend is responsible for
      *
-     * @param   ConfigObject    $config
+     * @param   string  $domain
      *
      * @return  $this
      */
-    public function setConfig(ConfigObject $config)
+    public function setDomain($domain)
     {
-        return $this
-            ->setBaseDn($config->base_dn)
-            ->setUserClass($config->user_class)
-            ->setUserNameAttribute($config->user_name_attribute)
-            ->setFilter($config->filter);
+        if ($domain && ($domain = trim($domain))) {
+            $this->domain = $domain;
+        }
+
+        return $this;
     }
 
     /**
@@ -372,10 +386,20 @@ class LdapUserBackend extends LdapRepository implements UserBackendInterface, In
      */
     public function authenticate(User $user, $password)
     {
+        if ($this->domain !== null) {
+            if (! $user->hasDomain() || strtolower($user->getDomain()) !== strtolower($this->domain)) {
+                return false;
+            }
+
+            $username = $user->getLocalUsername();
+        } else {
+            $username = $user->getUsername();
+        }
+
         try {
             $userDn = $this
                 ->select()
-                ->where('user_name', str_replace('*', '', $user->getUsername()))
+                ->where('user_name', str_replace('*', '', $username))
                 ->getQuery()
                 ->setUsePagedResults(false)
                 ->fetchDn();
@@ -392,7 +416,7 @@ class LdapUserBackend extends LdapRepository implements UserBackendInterface, In
         } catch (LdapException $e) {
             throw new AuthenticationException(
                 'Failed to authenticate user "%s" against backend "%s". An exception was thrown:',
-                $user->getUsername(),
+                $username,
                 $this->getName(),
                 $e
             );
