@@ -3,6 +3,7 @@
 
 namespace Icinga\Chart\Primitive;
 
+use DOMDocument;
 use DOMElement;
 use Icinga\Chart\Render\RenderContext;
 use Icinga\Chart\Format;
@@ -164,10 +165,10 @@ class PieSlice extends Animatable implements Drawable
         $midX += intval($r/2 * sin(M_PI/9)) * ($midRadius > M_PI ? -1 : 1);
         $midY -= intval($r/2 * cos(M_PI/3)) * ($midRadius < M_PI*1.4 && $midRadius > M_PI/3 ? -1 : 1);
 
-        if ($ctx->ytoRelative($midY) > 100) {
+        if ($ctx->yToRelative($midY) > 100) {
             $midY = $ctx->yToAbsolute(100);
-        } elseif ($ctx->ytoRelative($midY) < 0) {
-            $midY = $ctx->yToAbsolute($ctx->ytoRelative(100+$midY));
+        } elseif ($ctx->yToRelative($midY) < 0) {
+            $midY = $ctx->yToAbsolute($ctx->yToRelative(100+$midY));
         }
 
         $path->append(array($midX , $midY));
@@ -279,9 +280,22 @@ class PieSlice extends Animatable implements Drawable
         $slicePath = $doc->createElement('path');
 
         $slicePath->setAttribute('d', $this->getPieSlicePath($x, $y, $r));
-        $slicePath->setAttribute('style', $this->getStyle());
         $slicePath->setAttribute('data-icinga-graph-type', 'pieslice');
 
+        $id = $this->id ?? uniqid('slice-');
+        $slicePath->setAttribute('id', $id);
+        $this->setId($id);
+
+        $style = new DOMDocument();
+        $style->loadHTML($this->getStyle());
+
+        $slicePath->appendChild(
+            $slicePath->ownerDocument->importNode(
+                $style->getElementsByTagName('style')->item(0),
+                true
+            )
+        );
+
         $this->applyAttributes($slicePath);
         $group->appendChild($slicePath);
         if ($this->caption != "") {
