@@ -33,6 +33,14 @@ abstract class Filter
 
     abstract public function orFilter(Filter $filter);
 
+    /**
+     * Whether the give row matches this Filter
+     *
+     * @param mixed $row Preferrably an stdClass instance
+     * @return bool
+     */
+    abstract public function matches($row);
+
     public function getUrlParams()
     {
         return UrlParams::fromQueryString($this->toQueryString());
@@ -90,7 +98,7 @@ abstract class Filter
             }
         }
 
-        krsort($operators, version_compare(PHP_VERSION, '5.4.0') >= 0 ? SORT_NATURAL : SORT_REGULAR);
+        krsort($operators, SORT_NATURAL);
         foreach ($operators as $id => $operator) {
             $f = $filter->getById($id);
             if ($f->getOperatorName() !== $operator) {
@@ -133,7 +141,7 @@ abstract class Filter
      * @param string $filter  Filter expression
      *
      * @throws FilterException
-     * @return FilterWhere
+     * @return FilterExpression
      */
     public static function where($col, $filter)
     {
@@ -143,16 +151,23 @@ abstract class Filter
     public static function expression($col, $op, $expression)
     {
         switch ($op) {
-            case '=': return new FilterMatch($col, $op, $expression);
-            case '<': return new FilterLessThan($col, $op, $expression);
-            case '>': return new FilterGreaterThan($col, $op, $expression);
-            case '>=': return new FilterEqualOrGreaterThan($col, $op, $expression);
-            case '<=': return new FilterEqualOrLessThan($col, $op, $expression);
-            case '!=': return new FilterMatchNot($col, $op, $expression);
-            default: throw new ProgrammingError(
-                'There is no such filter sign: %s',
-                $op
-            );
+            case '=':
+                return new FilterMatch($col, $op, $expression);
+            case '<':
+                return new FilterLessThan($col, $op, $expression);
+            case '>':
+                return new FilterGreaterThan($col, $op, $expression);
+            case '>=':
+                return new FilterEqualOrGreaterThan($col, $op, $expression);
+            case '<=':
+                return new FilterEqualOrLessThan($col, $op, $expression);
+            case '!=':
+                return new FilterMatchNot($col, $op, $expression);
+            default:
+                throw new ProgrammingError(
+                    'There is no such filter sign: %s',
+                    $op
+                );
         }
     }
 
@@ -213,9 +228,12 @@ abstract class Filter
     public static function chain($operator, $filters = array())
     {
         switch ($operator) {
-            case 'AND': return self::matchAll($filters);
-            case 'OR' : return self::matchAny($filters);
-            case 'NOT': return self::not($filters);
+            case 'AND':
+                return self::matchAll($filters);
+            case 'OR':
+                return self::matchAny($filters);
+            case 'NOT':
+                return self::not($filters);
         }
         throw new ProgrammingError(
             '"%s" is not a valid filter chain operator',
