@@ -56,6 +56,7 @@ class StyleSheet
         'css/vendor/normalize.css',
         'css/icinga/base.less',
         'css/icinga/badges.less',
+        'css/icinga/configmenu.less',
         'css/icinga/mixins.less',
         'css/icinga/grid.less',
         'css/icinga/nav.less',
@@ -79,7 +80,8 @@ class StyleSheet
         'css/icinga/modal.less',
         'css/icinga/audit.less',
         'css/icinga/health.less',
-        'css/icinga/php-diff.less'
+        'css/icinga/php-diff.less',
+        'css/icinga/pending-migration.less',
     ];
 
     /**
@@ -108,15 +110,12 @@ class StyleSheet
 
     /**
      * Create the StyleSheet
-     *
-     * @param bool $disableModes Disable replacing compiled Less colors with CSS var() function calls and don't inject
-     *                           light mode calls
      */
-    public function __construct($disableModes = false)
+    public function __construct()
     {
         $app = Icinga::app();
         $this->app = $app;
-        $this->lessCompiler = new LessCompiler($disableModes);
+        $this->lessCompiler = new LessCompiler();
         $this->pubPath = $app->getBaseDir('public');
         $this->collect();
     }
@@ -140,6 +139,7 @@ class StyleSheet
             $this->lessCompiler->addLessFile($this->pubPath . '/' . $lessFile);
         }
 
+        $auth = Auth::getInstance();
         $mm = $this->app->getModuleManager();
 
         foreach ($mm->getLoadedModules() as $moduleName => $module) {
@@ -158,7 +158,6 @@ class StyleSheet
         }
 
         if (! (bool) $themingConfig->get('disabled', false)) {
-            $auth = Auth::getInstance();
             if ($auth->isAuthenticated()) {
                 $userTheme = $auth->getUser()->getPreferences()->getValue('icingaweb', 'theme');
                 if ($userTheme !== null) {
@@ -175,7 +174,7 @@ class StyleSheet
                 Logger::warning(sprintf(
                     'Theme "%s" set by user "%s" has not been found.',
                     $theme,
-                    ($user = Auth::getInstance()->getUser()) !== null ? $user->getUsername() : 'anonymous'
+                    $auth->isAuthenticated() ? $auth->getUser()->getUsername() : 'anonymous'
                 ));
             }
         }
@@ -185,10 +184,10 @@ class StyleSheet
         }
 
         $mode = 'none';
-        if ($user = Auth::getInstance()->getUser()) {
+        if ($auth->isAuthenticated()) {
             $file = $themePath !== null ? @file_get_contents($themePath) : false;
             if (! $file || strpos($file, self::LIGHT_MODE_IDENTIFIER) !== false) {
-                $mode = $user->getPreferences()->getValue('icingaweb', 'theme_mode', self::DEFAULT_MODE);
+                $mode = $auth->getUser()->getPreferences()->getValue('icingaweb', 'theme_mode', self::DEFAULT_MODE);
             }
         }
 
@@ -246,13 +245,11 @@ class StyleSheet
      *
      * Does not cache the stylesheet if the HTTP header Cache-Control or Pragma is set to no-cache.
      *
-     * @param bool $minified     Whether to compress the stylesheet
-     * @param bool $disableModes Disable replacing compiled Less colors with CSS var() function calls and don't inject
-     *                           light mode calls
+     * @param   bool    $minified   Whether to compress the stylesheet
      */
-    public static function send($minified = false, $disableModes = false)
+    public static function send($minified = false)
     {
-        $styleSheet = new self($disableModes);
+        $styleSheet = new self();
 
         $request = $styleSheet->app->getRequest();
         $response = $styleSheet->app->getResponse();
@@ -314,6 +311,19 @@ class StyleSheet
         $app = Icinga::app();
 
         if ($theme && $theme !== self::DEFAULT_THEME) {
+            if (Hook::has('ThemeLoader')) {
+                try {
+                    $path = Hook::first('ThemeLoader')->getThemeFile($theme);
+                } catch (Exception $e) {
+                    Logger::error('Failed to call ThemeLoader hook: %s', $e);
+                    $path = null;
+                }
+
+                if ($path !== null) {
+                    return $path;
+                }
+            }
+
             if (($pos = strpos($theme, '/')) !== false) {
                 $moduleName = substr($theme, 0, $pos);
                 $theme = substr($theme, $pos + 1);
