@@ -3,17 +3,17 @@
 
 namespace Icinga\Web\Widget;
 
+use Exception;
+use Icinga\Application\Icinga;
+use Icinga\Data\Filter\Filter;
+use Icinga\Data\Filter\FilterChain;
+use Icinga\Data\Filter\FilterExpression;
+use Icinga\Data\Filter\FilterOr;
 use Icinga\Data\Filterable;
 use Icinga\Data\FilterColumns;
-use Icinga\Data\Filter\Filter;
-use Icinga\Data\Filter\FilterExpression;
-use Icinga\Data\Filter\FilterChain;
-use Icinga\Data\Filter\FilterOr;
-use Icinga\Web\Url;
-use Icinga\Application\Icinga;
 use Icinga\Exception\ProgrammingError;
 use Icinga\Web\Notification;
-use Exception;
+use Icinga\Web\Url;
 
 /**
  * Filter
@@ -63,7 +63,7 @@ class FilterEditor extends AbstractWidget
     protected $visible = true;
 
     /**
-     * Create a new FilterWidget
+     * Create a new FilterEditor
      *
      * @param Filter $filter Your filter
      */
@@ -274,7 +274,7 @@ class FilterEditor extends AbstractWidget
                         $filter = Filter::matchAll();
                     }
                     $filters = array();
-                    $search = ltrim($search);
+                    $search = trim($search);
                     foreach ($this->searchColumns as $searchColumn) {
                         $filters[] = Filter::expression($searchColumn, '=', "*$search*");
                     }
@@ -285,12 +285,13 @@ class FilterEditor extends AbstractWidget
                 }
             }
 
-            $url = $this->url()->setQueryString(
-                $filter->toQueryString()
-            )->addParams($preserve);
-            if ($modify) {
-                $url->getParams()->add('modifyFilter');
+            $url = Url::fromRequest()->onlyWith($this->preserveParams);
+            $urlParams = $url->getParams();
+            $url->setQueryString($filter->toQueryString());
+            foreach ($urlParams->toArray(false) as $key => $value) {
+                $url->getParams()->addEncoded($key, $value);
             }
+
             $this->redirectNow($url);
         }
 
@@ -470,7 +471,7 @@ class FilterEditor extends AbstractWidget
         }
 
         if ($this->addTo && $this->addTo == $filter->getId()) {
-            $parts[] = '<li style="background: #ffb">' . $this->renderNewFilter() .$this->cancelLink(). '</li>';
+            $parts[] = '<li class="new-filter">' . $this->renderNewFilter() .$this->cancelLink(). '</li>';
         }
 
         $class = $level === 0 ? ' class="datafilter"' : '';
@@ -574,7 +575,7 @@ class FilterEditor extends AbstractWidget
             $this->elementId('operator', $filter),
             $ops,
             $filter === null ? null : $filter->getOperatorName(),
-            array('style' => 'width: 5em')
+            ['class' => 'filter-operator']
         );
     }
 
@@ -593,7 +594,7 @@ class FilterEditor extends AbstractWidget
             $this->elementId('sign', $filter),
             $signs,
             $filter === null ? null : $filter->getSign(),
-            array('style' => 'width: 4em')
+            ['class' => 'filter-rule']
         );
     }
 
@@ -736,10 +737,11 @@ class FilterEditor extends AbstractWidget
         $preservedUrl = $this->preservedUrl();
 
         $html = ' <form method="post" class="search inline" action="'
-              . $preservedUrl
-              . '"><input type="text" name="q" style="width: 8em" class="search" value="" placeholder="'
-              . t('Search...')
-              . '" /></form>';
+            . $preservedUrl
+            . '"><i class="icon fa-search fa search-icon"></i>'
+            . '<input type="text" name="q" class="search search-input" value="" placeholder="'
+            . t('Search...')
+            . '" /></form>';
 
         if ($this->filter->isEmpty()) {
             $title = t('Filter this list');
@@ -768,23 +770,23 @@ class FilterEditor extends AbstractWidget
             return '';
         }
         if (! $this->preservedUrl()->getParam('modifyFilter')) {
-            return '<div class="filter">'
+            return '<div class="filter icinga-controls">'
                 . $this->renderSearch()
                 . $this->view()->escape($this->shorten($this->filter, 50))
                 . '</div>';
         }
-        return  '<div class="filter">'
+        return  '<div class="filter icinga-controls">'
             . $this->renderSearch()
             . '<form action="'
             . Url::fromRequest()
             . '" class="editor" method="POST">'
-            . '<input type="submit" name="submit" value="Apply" style="display:none;"/>'
+            . '<input type="submit" name="submit" value="Apply" hidden/>'
             . '<ul class="tree"><li>'
             . $this->renderFilter($this->filter)
             . '</li></ul>'
             . '<div class="buttons">'
-            . '<input type="submit" name="submit" value="Apply" />'
-            . '<input type="submit" name="cancel" value="Cancel" />'
+            . '<input type="submit" name="cancel" value="Cancel" class="button btn-cancel" />'
+            . '<input type="submit" name="submit" value="Apply" class="button btn-primary"/>'
             . '</div>'
             . '<input type="hidden" name="formUID" value="FilterEditor">'
             . '</form>'
