@@ -3,6 +3,7 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\FilterExpression;
 use Zend_Db_Expr;
 use Zend_Db_Select;
 use Icinga\Data\Filter\Filter;
@@ -22,9 +23,11 @@ class NotificationQuery extends IdoQuery
      */
     protected $columnMap = array(
         'notifications' => array(
+            'id'                            => 'n.id',
             'instance_name'                 => 'n.instance_name',
             'notification_contact_name'     => 'n.notification_contact_name',
             'notification_output'           => 'n.notification_output',
+            'notification_reason'           => 'n.notification_reason',
             'notification_state'            => 'n.notification_state',
             'notification_timestamp'        => 'n.notification_timestamp'
         ),
@@ -128,4 +131,14 @@ class NotificationQuery extends IdoQuery
         }
         return $this;
     }
+
+    public function whereEx(FilterExpression $ex)
+    {
+        $this->requireColumn($ex->getColumn());
+        foreach ($this->subQueries as $sub) {
+            $sub->whereEx($ex);
+        }
+
+        return $this;
+    }
 }
