@@ -24,6 +24,13 @@ class AddCommentCommand extends WithCommentCommand
      */
     protected $persistent;
 
+    /**
+     * Optional time when the acknowledgement should expire
+     *
+     * @var int|null
+     */
+    protected $expireTime;
+
     /**
      * Set whether the comment is persistent
      *
@@ -46,4 +53,28 @@ class AddCommentCommand extends WithCommentCommand
     {
         return $this->persistent;
     }
+
+    /**
+     * Set the time when the acknowledgement should expire
+     *
+     * @param   int $expireTime
+     *
+     * @return  $this
+     */
+    public function setExpireTime($expireTime)
+    {
+        $this->expireTime = (int) $expireTime;
+
+        return $this;
+    }
+
+    /**
+     * Get the time when the acknowledgement should expire
+     *
+     * @return int|null
+     */
+    public function getExpireTime()
+    {
+        return $this->expireTime;
+    }
 }
