@@ -1,5 +1,5 @@
 <?php
-/* Icinga Web 2 | (c) 2013-2015 Icinga Development Team | GPLv2+ */
+/* Icinga Web 2 | (c) 2013 Icinga Development Team | GPLv2+ */
 
 namespace Icinga\Module\Monitoring\DataView;
 
@@ -11,12 +11,8 @@ class EventHistory extends DataView
     public function getColumns()
     {
         return array(
+            'id',
             'instance_name',
-            'cnt_notification',
-            'cnt_hard_state',
-            'cnt_soft_state',
-            'cnt_downtime_start',
-            'cnt_downtime_end',
             'host_name',
             'host_display_name',
             'service_description',
